[% 
    htmltitle = 'Rock Family Tree' ;
    title = htmltitle ;

    crumb2_name = 'Profiles' ;
    crumb2_href = '/who/list' ;
    crumb1_name = 'Rock Family Tree' ;
%]

<div class="blocker">
<p>Here lies the story of ARK, in the form of a rock family tree.</p>
</div>

<hr width="80%">

<div class="blackbox" width="520">
  <table width="500" align="center" border="0" cellpadding="0" cellspacing="0">
	<tr>
    <td colspan="5"><center><h1><em><u>The ARK Family History</u></em></h1></center></td>
	</tr>
	<tr>
    <td colspan="5"><center>
      <table width="80%" border="0" cellpadding="0" cellspacing="0">	
      <tr><td><center><b>DAMASCUS #1 [198?]</b></center></td></tr></table>
      </center>
    </td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100"><b>Jim Grey</b></td>
    <td width="100"><b>Steve Shilvok</b></td>
    <td width="100"><b>Dave Cooper</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>keyboards</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"> </td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"> </td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"> </td>
    <td align="center">&nbsp; </td>
    <td align="center">&nbsp; </td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp; </td>
    <td align="center">&nbsp; </td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"> </td>
    <td align="center">&nbsp; </td>
    <td align="center">&nbsp; </td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%" border="0" cellpadding="0" cellspacing="0">	<tr>	  
    <td>		<center>		  <b>DAMASCUS #2 [198?]</b>		</center>	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100"><b>Steve Nash</b></td>
    <td width="100"><b>Andy Harris</b></td>
    <td width="100"><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>keyboards</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%" border="0" cellpadding="0" cellspacing="0">	<tr>	  
    <td>		<center>		  <b>DAMASCUS #3 [198?]</b>		</center>	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100">&nbsp;</td>
    <td width="100"><b>Andy Harris</b></td>
    <td width="100"><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>&nbsp;</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%" border="0" cellpadding="0" cellspacing="0">	<tr>	  
    <td>		<center>		  <b>DAMASCUS #4 [198?]</b>		</center>	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100"><b>Steve Harris</b></td>
    <td width="100"><b>Andy Harris</b></td>
    <td width="100"><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%" border="0" cellpadding="0" cellspacing="0">	<tr>	  
    <td>		<center>		  <b>KITE [1986]</b>		</center>	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100"><b>Steve Harris</b></td>
    <td width="100"><b>Andy Harris</b></td>
    <td width="100"><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%" border="0" cellpadding="0" cellspacing="0">	<tr>	  
    <td> <b>ARK #1 [1986]</b> Following several ideas for a new name,		in 1986 the band settled on ARK. The band then set about building		up the following the had with several gigs around the West Midlands.	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td width="100"><b>Ant Short</b></td>
    <td width="100"><b>Pete Wheatley</b></td>
    <td width="100"><b>Steve Harris</b></td>
    <td width="100"><b>Andy Harris</b></td>
    <td width="100"><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line08.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%">	<tr>	  
    <td> <b>ARK #2 [1986-1988]</b> Having spent several seesions in		the recording studio, the band were able to fund the release of		their first few cassette only singles, as well as their first		appearance on vinyl with the 7" single Communications. </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr>
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>John Jowitt</b></td>
    <td><b>Dave Robbins</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%">	<tr>	  
    <td> <b>ARK #3 [1988-1989]</b> Won a Battle of The Bands competition		at Edwards No.8 in Birmingham, and found themselves in the studio		recording their first album, The Dreams Of Mr Jones. </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>John Jowitt</b></td>
    <td><b>Gary Davis</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%">	<tr>	  
    <td> <b>ARK #4 [1989-1990]</b> Further recording session saw the		release of the 12" EP New Scientist, together with the 2 cassette		albums, Stand Alone &amp; Archives, both of which were collections		of studio demos, that never made previously made it onto record.	  </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>John Jowitt</b></td>
    <td><b>Richard Deane</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line08.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%">	<tr>	  
    <td> <b>ARK #5 [1990-1991]</b> Played several show around the UK,		and began writing with a view to recording their first proper		album. </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>Gel Newey</b></td>
    <td><b>Richard Deane</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>  <table width="80%">	<tr>	  
    <td> <b>ARK #6 [1991-1995]</b> Following a session at Rich Bitch		recording studio, the band recorded what was to be the basis of		the Cover Me With Rain EP. However, prior to release, the band		sent in a tape to Tommy Vance for his 'Rock Wars' feature on the		Friday Rock Show on Radio One. The highest recorded number of		votes (curiously all from the Midlands) gained the band a Radio		One session. 4 tracks, plus a jingle, were recorded in Maida Vale.		As the session was aired, the Cover Me With Rain EP was also released,		helping to increase the fan base. Following numerous trips around		the UK and mainland Europe, the band recorded their final album,		Spiritual Physics. Sadly the band split on 13th March 1995 at		the Flapper &amp; Firkin in Birmingham. </td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>Gel Newey</b></td>
    <td><b>Paul Rodgers</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line05.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>
      <table width="80%">	
      <tr>	  
        <td> <b>ARK #7 [1995]</b> In early 1995 Paul left the band and was		replaced for the farewell tour by Hugh Edwards. The band played		their last gig on 13th March 1995 at the Flapper &amp; Firkin
                in Birmingham. The final night featured several ex-members
                joining the band on stage for one last time.</td>	</tr>  </table></center></td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>Gel Newey</b></td>
    <td><b>Hugh Edwards</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>  
	<tr valign="bottom">
    <td align="center"><img src="/img/line04.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line06.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line10.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr valign="top">
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
    <td align="center"><img src="/img/line09.gif" width="100" height="35"></td>
    <td align="center">&nbsp;</td>
    <td align="center">&nbsp;</td>
	</tr>
	<tr>
    <td colspan="5"><center>
      <table width="80%">	
      <tr>	  
        <td> <b>ARK #8 [2009-]</b> In 2008/9 the guys got back in contact with each other and discussed the possibility of doing some reunion gigs. After some rehearsals together in 2009, a plan came together to record some classic tracks and do some gigs. Now to see if they've Finally Made It!</td>
      </tr>  
      </table>
      </center>
    </td>
	</tr>
	<tr>
    <td align="center"><img src="/img/line02.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line01.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line07.gif" width="100" height="35"></td>
    <td align="center"><img src="/img/line03.gif" width="100" height="35"></td>
	</tr>
	<tr valign="top">
    <td><b>Ant Short</b></td>
    <td><b>Pete Wheatley</b></td>
    <td><b>Steve Harris</b></td>
    <td><b>John Jowitt</b></td>
    <td><b>Tim Churchman</b></td>
	</tr>
	<tr valign="top">
    <td>vocals &amp; flute</td>
    <td>lead guitar &amp; backing vocals</td>
    <td>guitar synthesizer</td>
    <td>bass guitar &amp; backing vocals</td>
    <td>drums</td>
	</tr>
	</table>
</div>
